@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,18 +22,23 @@
 
 #include <QWidget>
 #include "sieveeditorutil.h"
+#include "libsieveeditor_private_export.h"
 
 namespace Ui
 {
 class ServerSieveSettings;
 }
-
-class ServerSieveSettings : public QWidget
+namespace MailTransport
+{
+class ServerTest;
+}
+class QComboBox;
+class LIBSIEVEEDITOR_TESTS_EXPORT ServerSieveSettings : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit ServerSieveSettings(QWidget *parent = Q_NULLPTR);
+    explicit ServerSieveSettings(QWidget *parent = nullptr);
     ~ServerSieveSettings();
 
     QString serverName() const;
@@ -51,15 +56,35 @@ public:
     void setServerSieveConfig(const SieveEditorUtil::SieveServerConfig &conf);
     SieveEditorUtil::SieveServerConfig serverSieveConfig() const;
 
+    QString imapServerName() const;
+    void setImapServerName(const QString &name);
+
+    int imapPort() const;
+    void setImapPort(int value);
+
+    QString imapUserName() const;
+    void setImapUserName(const QString &name);
+
+    QString imapPassword() const;
+    void setImapPassword(const QString &pass);
+
+    void setAuthenticationType(KSieveUi::SieveImapAccountSettings::AuthenticationMode type);
+    KSieveUi::SieveImapAccountSettings::AuthenticationMode authenticationType() const;
 Q_SIGNALS:
     void enableOkButton(bool enabled);
 
 private Q_SLOTS:
     void slotUserServerNameChanged();
+    void slotTest();
 
+    void slotFinished(const QVector<int> &testResult);
+    void slotEncryptionRadioChanged();
 private:
-    void populateDefaultAuthenticationOptions();
+    void populateDefaultAuthenticationOptions(QComboBox *combobox);
+    void slotSafetyChanged();
+    void populateDefaultComboBoxAuthenticationOptions();
     Ui::ServerSieveSettings *ui;
+    MailTransport::ServerTest *mServerTest;
 };
 
 #endif // SERVERSIEVESETTINGS_H
