@@ -27,12 +27,20 @@
 SieveEditorConfigureServerPage::SieveEditorConfigureServerPage(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *hbox = new QHBoxLayout;
+    QHBoxLayout *hbox = new QHBoxLayout(this);
+    hbox->setSpacing(0);
     QPushButton *button = new QPushButton(i18n("Configure..."));
     button->setObjectName(QStringLiteral("configure_button"));
     button->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     connect(button, &QAbstractButton::clicked, this, &SieveEditorConfigureServerPage::configureClicked);
+
+    QPushButton *importSieveSettings = new QPushButton(i18n("Import Sieve Settings..."));
+    importSieveSettings->setObjectName(QStringLiteral("import_sieve_settings_button"));
+    importSieveSettings->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+    connect(importSieveSettings, &QAbstractButton::clicked, this, &SieveEditorConfigureServerPage::importSieveSettings);
+
     hbox->addWidget(button);
+    hbox->addWidget(importSieveSettings);
     setLayout(hbox);
 }
 
